@@ -1,18 +1,29 @@
-#===============================================================================
-# Copyright 2009 Matt Chaput
-# 
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-# 
-#    http://www.apache.org/licenses/LICENSE-2.0
-# 
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-#===============================================================================
+# Copyright 2009 Matt Chaput. All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#
+#    1. Redistributions of source code must retain the above copyright notice,
+#       this list of conditions and the following disclaimer.
+#
+#    2. Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#
+# THIS SOFTWARE IS PROVIDED BY MATT CHAPUT ``AS IS'' AND ANY EXPRESS OR
+# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
+# EVENT SHALL MATT CHAPUT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
+# OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
+# EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#
+# The views and conclusions contained in the software and documentation are
+# those of the authors and should not be interpreted as representing official
+# policies, either expressed or implied, of Matt Chaput.
 
 from bisect import bisect_left
 from heapq import nlargest, nsmallest
@@ -151,8 +162,11 @@ class SegmentReader(IndexReader):
 
     @protected
     def has_vector(self, docnum, fieldname):
-        self._open_vectors()
-        return (docnum, fieldname) in self.vectorindex
+        if self.schema[fieldname].vector:
+            self._open_vectors()
+            return (docnum, fieldname) in self.vectorindex
+        else:
+            return False
 
     @protected
     def __iter__(self):
@@ -186,14 +200,12 @@ class SegmentReader(IndexReader):
             raise TermNotFound("%s:%r" % (fieldname, text))
 
     def doc_frequency(self, fieldname, text):
-        self._test_field(fieldname)
         try:
             return self._term_info(fieldname, text)[2]
         except TermNotFound:
             return 0
 
     def frequency(self, fieldname, text):
-        self._test_field(fieldname)
         try:
             return self._term_info(fieldname, text)[0]
         except TermNotFound:
@@ -237,33 +249,13 @@ class SegmentReader(IndexReader):
                     break
                 yield t
 
-#    def first_id(self, fieldname, text):
-#        id = None
-#        try:
-#            offset = self.termsindex[fieldname, text][1]
-#        except KeyError:
-#            raise TermNotFound((fieldname, text))
-#        else:
-#            if isinstance(offset, (int, long)):
-#                format = self.schema[fieldname].format
-#                pr = FilePostingReader(self.postfile, offset, format)
-#                if pr.is_active():
-#                    id = pr.id()
-#            else:
-#                id = offset[0][0]
-#        
-#        if id is not None and not self.is_deleted(id):
-#            return id
-#        raise TermNotFound((fieldname, text))
-
     def postings(self, fieldname, text, scorer=None):
-        self._test_field(fieldname)
-        format = self.schema[fieldname].format
         try:
             offset = self.termsindex[fieldname, text][1]
         except KeyError:
             raise TermNotFound("%s:%r" % (fieldname, text))
 
+        format = self.schema[fieldname].format
         if isinstance(offset, (int, long)):
             postreader = FilePostingReader(self.postfile, offset, format,
                                            scorer=scorer, fieldname=fieldname,
